<?php

namespace InterludeSante\Statistics;

use InterludeSante\Statistics\Chart;

class Ajax
{
    private $name;
    private $establishment_id;

    /**
     * The single instance of the class.
     *
     * @since  1.0
     * @access protected
     */
    protected static $instance = null;

    /**
     * Main instance.
     *
     * Ensures only one instance is loaded or can be loaded.
     *
     * @since  1.0
     * @access public
     * @param  string $path
     *
     * @return Main instance.
     */
    public static function instance(string $path, string $name)
    {
        if (is_null(self::$instance)) {
            self::$instance = new self($path, $name);
        }
        return self::$instance;
    }

    public function __construct(string $path, string $name)
    {
        $this->path = $path;
        $this->name = $name;
        $this->establishment_id = !empty($_GET['establishment_id']) ? esc_html($_GET['establishment_id']) : 0;

        add_action('wp_ajax_updateDate', [$this, 'updateDate']);
        add_action('wp_ajax_updateSurvey', [$this, 'updateSurvey']);
        add_action('admin_enqueue_scripts', [$this, 'enqueueAssets']);
    }


    public function updateDate()
    {
        $name = esc_html($_GET['name']);
        $period = esc_html($_GET['period']);
        $order = esc_html($_GET['order']);
        $date = !empty($_GET['date']) ? esc_html($_GET['date']) : time();



        $chart = [];
        $order = $order === 'next' ? '+' : '-';

        if ($period === 'week') {
            $date = strtotime($order . '7 days', $date);
        }
        if ($period === 'month') {
            $date = strtotime($order . '12 months', $date);
        }

        if (!empty($name) && !empty($period)) {
            $chart = Chart::get($name, null, $period, $date);
        }

        wp_send_json_success(['chart' => $chart, 'date' => $date]);

        wp_die();
    }

    public function updateSurvey()
    {
        $name = esc_html($_GET['name']);
        $id = !empty($_GET['survey']) ? esc_html($_GET['survey']) : 0;
        $total = !empty($_GET['total']) ? esc_html($_GET['total']) : 0;
        $order = esc_html($_GET['order']);

        switch ($order) {
            case 'next':
                if ($id <= $total) {
                    $id++;
                }
                break;
            case 'previous':
                if ($id > 0) {
                    $id--;
                }
                break;
        }

        $chart = Chart::get($name, $id);

        wp_send_json_success(['chart' => $chart, 'survey_index' => $id]);

        wp_die();
    }

    public function enqueueAssets(string $hook_suffix)
    {
        if (strpos($hook_suffix, sanitize_key($this->name))) {
            wp_localize_script(sanitize_title($this->name) . '/charts', 'chartsData', [
                'ajaxurl' => admin_url('admin-ajax.php'),
                'establishment_id' => $this->establishment_id,
                'nonce' => wp_create_nonce('ajax-nonce')
            ]);
        }
    }
}
